@@ -5,7 +5,7 @@ use utf8;
 
 package Neo4j::Driver::Result;
 # ABSTRACT: Result of running a Cypher statement (a stream of records)
-$Neo4j::Driver::Result::VERSION = '0.45';
+$Neo4j::Driver::Result::VERSION = '0.46';
 
 use parent 'Neo4j::Driver::StatementResult';
 
@@ -225,7 +225,7 @@ Neo4j::Driver::Result - Result of running a Cypher statement (a stream of record
 
 =head1 VERSION
 
-version 0.45
+version 0.46
 
 =head1 SYNOPSIS
 
@@ -319,6 +319,7 @@ detach the result, but will never exhaust it.
  @keys = $result->keys;
 
 Retrieve the column names of the records this result contains.
+In scalar context, return the number of columns.
 
 =head2 list
 
@@ -380,22 +381,6 @@ way.
  $record = $transaction->run('...')->single;
  $result_summary = $record->summary;
 
-=head1 EXPERIMENTAL FEATURES
-
-L<Neo4j::Driver::Result> implements the following
-experimental features. These are subject to unannounced modification
-or removal in future versions. Expect your code to break if you
-depend upon these features.
-
-=head2 Calling in scalar context
-
- $count = $result->keys;
-
-The C<keys()> method returns the number of columns if called in scalar
-context.
-
-Until version 0.25, it returned an array reference instead.
-
 =head1 SEE ALSO
 
 =over
